You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@openoffice.apache.org by pf...@apache.org on 2014/04/29 21:05:21 UTC

svn commit: r1591058 [10/15] - in /openoffice/trunk/main: ./ accessibility/bridge/org/openoffice/java/accessibility/ accessibility/bridge/source/java/ accessibility/inc/accessibility/extended/ accessibility/inc/accessibility/standard/ accessibility/sou...

Modified: openoffice/trunk/main/framework/inc/classes/filtercachedata.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/classes/filtercachedata.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/inc/classes/filtercachedata.hxx (original)
+++ openoffice/trunk/main/framework/inc/classes/filtercachedata.hxx Tue Apr 29 19:05:05 2014
@@ -73,7 +73,7 @@ namespace framework{
 
 #define PACKAGENAME_TYPEDETECTION_STANDARD          DECLARE_ASCII("Office.TypeDetection"                            )   /// Names of our configuration files.
 #define PACKAGENAME_TYPEDETECTION_ADDITIONAL        DECLARE_ASCII("Office.TypeDetectionAdditional"                  )
-#define CFG_PATH_SEPERATOR                          DECLARE_ASCII("/"                                               )   /// seperator for configuration pathes
+#define CFG_PATH_SEPERATOR                          DECLARE_ASCII("/"                                               )   /// seperator for configuration paths
 #define PROPERTY_SEPERATOR                          sal_Unicode(',')                                                    /// seperator for own formated property strings of types and filters
 #define LIST_SEPERATOR                              sal_Unicode(';')                                                    /// seperator for own formated lists as part of our own formated type- or filter-string
 #define LOCALE_FALLBACK                             DECLARE_ASCII("en-US"                                           )   /// fallback, if configuration can't give us current set locale ...
@@ -469,7 +469,7 @@ class SetNodeHash : public ::std::hash_m
     //-------------------------------------------------------------------------------------------------------------
 	public:
         //---------------------------------------------------------------------------------------------------------
-        // The only way to free ALL memory realy!
+        // The only way to free ALL memory really!
         //---------------------------------------------------------------------------------------------------------
         inline void free()
         {
@@ -481,7 +481,7 @@ class SetNodeHash : public ::std::hash_m
 
         //---------------------------------------------------------------------------------------------------------
         // Append changed, added or removed items to special lists
-        // Neccessary for saving changes
+        // Necessary for saving changes
         //---------------------------------------------------------------------------------------------------------
         void appendChange( const ::rtl::OUString& sName  ,
                                  EModifyState     eState );
@@ -507,7 +507,7 @@ class PerformanceHash   :   public  ::st
 {
 	public:
         //---------------------------------------------------------------------------------------------------------
-        //  try to free all used memory REALY!
+        //  try to free all used memory REALLY!
         //---------------------------------------------------------------------------------------------------------
         inline void free()
         {
@@ -576,7 +576,7 @@ class DataContainer : private ThreadHelp
     /** @short  identifies different sets of the TypeDetection configuration package.
 
         @descr  Most functions on top of this configuration package are the same ...
-                but must be executed on different places inside ths configuration structures.
+                but must be executed on different places inside this configuration structures.
                 These enum values can be used ate some interface methods to specify, which
                 configuration set should be used.
                 Further it must be possible to start the same action for more then one cfg type.
@@ -778,8 +778,8 @@ class FilterCFGAccess : public ::utl::Co
     //  member
     //-------------------------------------------------------------------------------------------------------------
     private:
-        EFilterPackage  m_ePackage                     ;   // ... not realy used yet! should split configuration in STANDARD and ADDITIONAL filter
-        sal_Int32       m_nVersion                     ;   // file format version of configuration! (neccessary for "xml2xcd" transformation!)
+        EFilterPackage  m_ePackage                     ;   // ... not really used yet! should split configuration in STANDARD and ADDITIONAL filter
+        sal_Int32       m_nVersion                     ;   // file format version of configuration! (necessary for "xml2xcd" transformation!)
         sal_Int32       m_nKeyCountTypes               ;   // follow key counts present count of configuration properties for types/filters ... and depends from m_nVersion - must be set right!
         sal_Int32       m_nKeyCountFilters             ;
         sal_Int32       m_nKeyCountDetectors           ;
@@ -815,7 +815,7 @@ class FilterCFGListener : public  css::u
         DataContainer* m_pData;
 
         // we must know, if we are already registered as listener or not.
-        //    That can be usefull to supress double registration calls ...
+        //    That can be useful to suppress double registration calls ...
         //    which may will force double call backs in our disposing method!
         //    Such superflous calls can be dangerous.
         sal_Bool m_bListening;

Modified: openoffice/trunk/main/framework/inc/classes/framecontainer.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/classes/framecontainer.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/inc/classes/framecontainer.hxx (original)
+++ openoffice/trunk/main/framework/inc/classes/framecontainer.hxx Tue Apr 29 19:05:05 2014
@@ -99,7 +99,7 @@ class FrameContainer : private ThreadHel
 
         /// list to hold all frames
         TFrameContainer m_aContainer;
-        /// one container item can be the current active frame. Its neccessary for Desktop or Frame implementation.
+        /// one container item can be the current active frame. Its necessary for Desktop or Frame implementation.
         css::uno::Reference< css::frame::XFrame > m_xActiveFrame;
 /*DEPRECATEME
         /// indicates using of the automatic async quit feature in case last task will be closed

Modified: openoffice/trunk/main/framework/inc/classes/protocolhandlercache.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/classes/protocolhandlercache.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/inc/classes/protocolhandlercache.hxx (original)
+++ openoffice/trunk/main/framework/inc/classes/protocolhandlercache.hxx Tue Apr 29 19:05:05 2014
@@ -57,7 +57,7 @@ namespace framework{
 
 #define PACKAGENAME_PROTOCOLHANDLER                 DECLARE_ASCII("Office.ProtocolHandler"                          )   /// name of our configuration package
 
-#define CFG_PATH_SEPERATOR                          DECLARE_ASCII("/"                                               )   /// seperator for configuration pathes
+#define CFG_PATH_SEPERATOR                          DECLARE_ASCII("/"                                               )   /// seperator for configuration paths
 #define CFG_ENCODING_OPEN                           DECLARE_ASCII("[\'"                                             )   /// used to start encoding of set names
 #define CFG_ENCODING_CLOSE                          DECLARE_ASCII("\']"                                             )   /// used to finish encoding of set names
 
@@ -116,7 +116,7 @@ typedef BaseHash< ProtocolHandler > Hand
                         - another one maps her registered pattern to her uno names to
                           perform search on such data
                     But this lists a static for all instances of this class. So it's possible to
-                    create new objects without opening configuration twice and free memory automaticly
+                    create new objects without opening configuration twice and free memory automatically
                     if last object will gone.
 
     @attention      We implement a singleton concept - so we doesn't need any mutex member here.
@@ -165,7 +165,7 @@ class FWI_DLLPUBLIC HandlerCache
                     We set a data container pointer for filling or reading ... this class use it temp.
                     After successfuly calling of read(), we can use filled container directly or merge it with an existing one.
                     After successfuly calling of write() all values of given data container are flushed to our configuration -
-                    but current implementation doesn't support writeing realy.
+                    but current implementation doesn't support writeing really.
 
     @base           ::utl::ConfigItem
                     base mechanism for configuration access

Modified: openoffice/trunk/main/framework/inc/classes/servicemanager.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/classes/servicemanager.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/inc/classes/servicemanager.hxx (original)
+++ openoffice/trunk/main/framework/inc/classes/servicemanager.hxx Tue Apr 29 19:05:05 2014
@@ -63,7 +63,7 @@ namespace framework{
 
 /*-************************************************************************************************************//**
 	@short			create a new global servicemanager
-	@descr			A global servicemanager is neccessary to instanciate UNO-services. To do this, you need
+	@descr			A global servicemanager is necessary to instanciate UNO-services. To do this, you need
 					a factory to create new objects with special type. That's the reason for a servicemanager.
 
 	@implements		-
@@ -118,9 +118,9 @@ class ServiceManager
 			@short		initialize global uno service manager and return it
 			@descr		This method create a new manager only at first call. We confiscate this with a static
 						pointer, which will be initialized only, if it NULL!
-						Then you can call this method everytime to get a reference to the manager.
+						Then you can call this method every time to get a reference to the manager.
 						If you will initialize an uno application you must set returned reference in ::comphelper::setProcessServiceFactory()!
-						The created manager use "applicat.rdb" and "userXX.rdb" automaticly.
+						The created manager use "applicat.rdb" and "userXX.rdb" automatically.
 
 			@seealso	-
 
@@ -149,7 +149,7 @@ class ServiceManager
 		/*-****************************************************************************************************//**
 			@short		return a reference to a uno servicemanager instance which use your specified user registry file
 			@descr		This do the same like method before - but instead of "userXX.rdb" we use your file.
-						These is neccessary, if you will run more then one uno application at the same time in same environment!
+						These is necessary, if you will run more then one uno application at the same time in same environment!
 						All created servicemanager use the same "applicat.rdb" but different user registries.
 
 			@ATTENTION	Given file name must be a full qualified system file name. If file not already exist we create a new one!
@@ -211,7 +211,7 @@ class ServiceManager
 			@param		-
 			@return		reference to created static own global mutex
 
-			@onerror	No error should occure.
+			@onerror	No error should occur.
 		*//*-*****************************************************************************************************/
 
 		MUTEX& impl_getOwnGlobalMutex();
@@ -224,7 +224,7 @@ class ServiceManager
 
 			@param		"sRegistryFile", file name of user registry.
 			@return		A reference to a new initialized servicemanager with a valid registry.
-						It can be NULL, if an error occured.
+						It can be NULL, if an error occurred.
 
 			@onerror	Return a NULL-reference.
 		*//*-*****************************************************************************************************/

Modified: openoffice/trunk/main/framework/inc/commands.h
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/commands.h?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/inc/commands.h (original)
+++ openoffice/trunk/main/framework/inc/commands.h Tue Apr 29 19:05:05 2014
@@ -45,7 +45,7 @@ namespace framework{
 
 #define COMMAND_PLUGIN    DECLARE_ASCII("-plugin"     ) /// office is plugged into a browser
 #define COMMAND_HEADLESS  DECLARE_ASCII("-headless"   ) /// office runs in headless mode for scripting
-#define COMMAND_INVISIBLE DECLARE_ASCII("-invisible"  ) /// office runs in invisible mode which supress splash screen and first empry document
+#define COMMAND_INVISIBLE DECLARE_ASCII("-invisible"  ) /// office runs in invisible mode which suppress splash screen and first empry document
 #define COMMAND_SERVER    DECLARE_ASCII("-server"     ) /// office runs as server
 }		//	namespace framework
 

Modified: openoffice/trunk/main/framework/inc/dispatch/basedispatcher.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/dispatch/basedispatcher.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/inc/dispatch/basedispatcher.hxx (original)
+++ openoffice/trunk/main/framework/inc/dispatch/basedispatcher.hxx Tue Apr 29 19:05:05 2014
@@ -153,8 +153,8 @@ struct LoadBinding
         css::uno::Reference< css::frame::XDispatch >        xHandler    ;   // if handler was used, this reference will be valid
         css::uno::Reference< css::frame::XFrameLoader >     xLoader     ;   // if loader was used, this reference will be valid
         css::uno::Reference< css::frame::XFrame >           xFrame      ;   // Target of loading
-        css::util::URL                                      aURL        ;   // dispatched URL - neccessary to find listener for status event!
-        css::uno::Sequence< css::beans::PropertyValue >     lDescriptor ;   // dispatched arguments - neccessary for "reactForLoadingState()"!
+        css::util::URL                                      aURL        ;   // dispatched URL - necessary to find listener for status event!
+        css::uno::Sequence< css::beans::PropertyValue >     lDescriptor ;   // dispatched arguments - necessary for "reactForLoadingState()"!
         css::uno::Any                                       aAsyncInfo  ;   // superclasses could use them to save her own user specific data for these asynchron call-info
         css::uno::Reference< css::frame::XDispatchResultListener > xListener;
 };
@@ -228,7 +228,7 @@ class LoaderThreads : private ::std::vec
 
 /*-************************************************************************************************************//**
     @short          base class for dispatcher implementations
-    @descr          Most of our dispatch implementations do everytime the same. They try to handle or load
+    @descr          Most of our dispatch implementations do every time the same. They try to handle or load
                     somethinmg into a target ... normaly a frame/task/pluginframe!
                     They must do it synchron or sometimes asynchron. They must wait for callbacks and
                     notify registered listener with right status events.
@@ -255,7 +255,7 @@ class BaseDispatcher    :   // interface
                             public    css::frame::XNotifyingDispatch           ,
                             public    css::frame::XLoadEventListener           ,   // => XEventListener too!
                             // baseclasses
-                            // Order is neccessary for right initialization!
+                            // Order is necessary for right initialization!
                             protected ThreadHelpBase                           ,
                             protected TransactionBase                          ,
                             public    ::cppu::OWeakObject
@@ -311,7 +311,7 @@ class BaseDispatcher    :   // interface
                         task if operation failed ...!?
                         By overwriting these pure virtual methods it's possible to do such things.
                         We call you with all available informations ... you should react for it.
-                        BUT - don't send any status events to your listener! We will do it everytime.
+                        BUT - don't send any status events to your listener! We will do it every time.
                         (other listener could be informed as well!)
 
                         You will called back in: a) "reactForLoadingState()" , if URL was loaded into a frame

Modified: openoffice/trunk/main/framework/inc/dispatch/blankdispatcher.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/dispatch/blankdispatcher.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/inc/dispatch/blankdispatcher.hxx (original)
+++ openoffice/trunk/main/framework/inc/dispatch/blankdispatcher.hxx Tue Apr 29 19:05:05 2014
@@ -70,7 +70,7 @@ namespace framework{
     @threadsafe     yes
 *//*-*************************************************************************************************************/
 class BlankDispatcher   :   // -interfaces  ... are supported by our BaseDispatcher!
-                            // -baseclasses ... order is neccessary for right initialization!
+                            // -baseclasses ... order is necessary for right initialization!
                             public BaseDispatcher
 {
 	//-------------------------------------------------------------------------------------------------------------

Modified: openoffice/trunk/main/framework/inc/dispatch/closedispatcher.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/dispatch/closedispatcher.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/inc/dispatch/closedispatcher.hxx (original)
+++ openoffice/trunk/main/framework/inc/dispatch/closedispatcher.hxx Tue Apr 29 19:05:05 2014
@@ -65,13 +65,13 @@ namespace framework{
     @descr          These URLs implements a special functionality to close a document or the whole frame ...
                     and handle the state, it was the last frame or document. Then we create the
                     default backing document which can be used to open new ones using the file open dialog
-                    or some other menu entries. Or we terminate the whole application in case this backing mode shouldnt
+                    or some other menu entries. Or we terminate the whole application in case this backing mode shouldn't
                     be used.
  */
 class CloseDispatcher : public css::lang::XTypeProvider
                       , public css::frame::XNotifyingDispatch             // => XDispatch
                       , public css::frame::XDispatchInformationProvider
-                        // baseclasses ... order is neccessary for right initialization!
+                        // baseclasses ... order is necessary for right initialization!
                       , private ThreadHelpBase
                       , public  ::cppu::OWeakObject
 {
@@ -205,10 +205,10 @@ class CloseDispatcher : public css::lang
         //---------------------------------------
         /** @short  prepare m_xCloseFrame so it should be closeable without problems.
 
-            @descr  Thats needed to be shure, that the document cant disagree
+            @descr  Thats needed to be sure, that the document can't disagree
                     later with e.g. an office termination.
                     The problem: Closing of documents can show UI. If the user
-                    ignores it and open/close other documents, we cant know
+                    ignores it and open/close other documents, we can't know
                     which state the office has after closing of this frame.
 
             @param  bAllowSuspend
@@ -236,8 +236,8 @@ class CloseDispatcher : public css::lang
                     before (e.g. by calling implts_closeView()!
 
                     Otherwhise e.g. the XController->suspend()
-                    call isnt made and no UI warn the user about
-                    loosing document changes. Because the
+                    call isn't made and no UI warn the user about
+                    losing document changes. Because the
                     frame is closed ....
 
             @return [bool]
@@ -282,7 +282,7 @@ class CloseDispatcher : public css::lang
                     directly used as css::frame::DispatchResultState value.
 
             @param  aResult
-                    not used yet realy ...
+                    not used yet really ...
          */
         void implts_notifyResultListener(const css::uno::Reference< css::frame::XDispatchResultListener >& xListener,
                                                sal_Int16                                                   nState   ,
@@ -290,13 +290,13 @@ class CloseDispatcher : public css::lang
 
         //---------------------------------------
         /** @short  try to find the right target frame where this close request
-                    must be realy done.
+                    must be really done.
                     
             @descr  The problem behind: closing some resources depends sometimes from the
                     context where its dispatched. Sometimes the start frame of the dispatch
                     has to be closed itself (target=_self) ... sometimes it's parent frame
                     has to be closed - BUT(!) it means a parent frame containing a top level
-                    window. _top cant be used then for dispatch - because it adress TopFrames
+                    window. _top can't be used then for dispatch - because it address TopFrames
                     not frames containg top level windows. So normaly _magic (which btw does not
                     exists at the moment .-) ) should be used. So we interpret target=<empty>
                     as _magic !

Modified: openoffice/trunk/main/framework/inc/dispatch/createdispatcher.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/dispatch/createdispatcher.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/inc/dispatch/createdispatcher.hxx (original)
+++ openoffice/trunk/main/framework/inc/dispatch/createdispatcher.hxx Tue Apr 29 19:05:05 2014
@@ -77,7 +77,7 @@ namespace framework{
     @threadsafe     yes
 *//*-*************************************************************************************************************/
 class CreateDispatcher  :   // -interfaces  ... are supported by our BaseDispatcher!
-                            // -baseclasses ... order is neccessary for right initialization!
+                            // -baseclasses ... order is necessary for right initialization!
                             public BaseDispatcher
 {
 	//-------------------------------------------------------------------------------------------------------------

Modified: openoffice/trunk/main/framework/inc/dispatch/dispatchprovider.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/dispatch/dispatchprovider.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/inc/dispatch/dispatchprovider.hxx (original)
+++ openoffice/trunk/main/framework/inc/dispatch/dispatchprovider.hxx Tue Apr 29 19:05:05 2014
@@ -66,7 +66,7 @@ namespace framework{
 //_________________________________________________________________________________________________________________
 
 /**
-    @descr          We know some special dispatch objects with diffrent functionality.
+    @descr          We know some special dispatch objects with different functionality.
                     The can be created internaly by the following DispatchProvider.
                     Here we define some identifier to force creation of the right one.
 */
@@ -108,7 +108,7 @@ class DispatchProvider  :   // interface
                             public  css::lang::XTypeProvider            ,
                             public  css::frame::XDispatchProvider       ,
 							// baseclasses
-							// Order is neccessary for right initialization!
+							// Order is necessary for right initialization!
                             private ThreadHelpBase                      ,
                             private TransactionBase                     ,
                             public  ::cppu::OWeakObject

Modified: openoffice/trunk/main/framework/inc/dispatch/helpagentdispatcher.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/dispatch/helpagentdispatcher.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/inc/dispatch/helpagentdispatcher.hxx (original)
+++ openoffice/trunk/main/framework/inc/dispatch/helpagentdispatcher.hxx Tue Apr 29 19:05:05 2014
@@ -42,7 +42,7 @@ namespace framework
 
 // define css alias ... and undefine it at the end of this file !!!
 #ifdef css
-	#error "I tried to use css as namespace define inside non exported header ... but it was already defined by somwhere else. .-)"
+	#error "I tried to use css as namespace define inside non exported header ... but it was already defined by somewhere else. .-)"
 #else
 	#define css ::com::sun::star
 #endif

Modified: openoffice/trunk/main/framework/inc/dispatch/interceptionhelper.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/dispatch/interceptionhelper.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/inc/dispatch/interceptionhelper.hxx (original)
+++ openoffice/trunk/main/framework/inc/dispatch/interceptionhelper.hxx Tue Apr 29 19:05:05 2014
@@ -260,7 +260,7 @@ class InterceptionHelper : public  css::
 
             @descr It capsulate more then one queryDispatch() requests and return a lits of dispatch objects
                    as result. Because both lists (in and out) coreespond together, it's not allowed to
-                   pack it - means supress NULL references!
+                   pack it - means suppress NULL references!
 
             @param lDescriptor
                     a list of queryDispatch() arguments.

Modified: openoffice/trunk/main/framework/inc/dispatch/mailtodispatcher.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/dispatch/mailtodispatcher.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/inc/dispatch/mailtodispatcher.hxx (original)
+++ openoffice/trunk/main/framework/inc/dispatch/mailtodispatcher.hxx Tue Apr 29 19:05:05 2014
@@ -70,7 +70,7 @@ namespace framework{
 /**
     @short          protocol handler for "mailto:" URLs
     @descr          It's a special dispatch object which is used registered for "mailto:*" URLs and
-                    will be automaticly used from the framework dispatch mechanism if such URL occured.
+                    will be automatically used from the framework dispatch mechanism if such URL occurred.
 
     @base           ThreadHelpBase
                         exports a lock member to guarantee right initialize value of it
@@ -87,7 +87,7 @@ class MailToDispatcher : // interfaces
                          public  css::frame::XDispatchProvider ,
                          public  css::frame::XNotifyingDispatch, // => XDispatch
                          // baseclasses
-                         // Order is neccessary for right initialization!
+                         // Order is necessary for right initialization!
                          private ThreadHelpBase                ,
                          public  cppu::OWeakObject
 {

Modified: openoffice/trunk/main/framework/inc/dispatch/menudispatcher.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/dispatch/menudispatcher.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/inc/dispatch/menudispatcher.hxx (original)
+++ openoffice/trunk/main/framework/inc/dispatch/menudispatcher.hxx Tue Apr 29 19:05:05 2014
@@ -106,7 +106,7 @@ class MenuDispatcher   :   // interfaces
 								public css::frame::XDispatch			,
 								public css::frame::XFrameActionListener	,
 								// baseclasses
-								// Order is neccessary for right initialization!
+								// Order is necessary for right initialization!
 								public ThreadHelpBase						,
 								public cppu::OWeakObject
 {
@@ -122,7 +122,7 @@ class MenuDispatcher   :   // interfaces
 
 		/*-****************************************************************************************************//**
 			@short		standard ctor
-			@descr		These initialize a new instance of ths class with needed informations for work.
+			@descr		These initialize a new instance of this class with needed informations for work.
 
 			@seealso	using at owner
 
@@ -149,7 +149,7 @@ class MenuDispatcher   :   // interfaces
 
 		/*-****************************************************************************************************//**
 			@short      dispatch URL with arguments
-			@descr		Every dispatch create a new task. If load of URL failed task will deleted automaticly!
+			@descr		Every dispatch create a new task. If load of URL failed task will deleted automatically!
 
 			@seealso	-
 
@@ -171,7 +171,7 @@ class MenuDispatcher   :   // interfaces
 			@seealso	method loadCancelled()
 
 			@param		"xControl"	, css::uno::Reference to a valid listener for state events.
-			@param		"aURL"		, URL about listener will be informed, if something occured.
+			@param		"aURL"		, URL about listener will be informed, if something occurred.
 			@return		-
 
 			@onerror	-

Modified: openoffice/trunk/main/framework/inc/dispatch/oxt_handler.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/dispatch/oxt_handler.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/inc/dispatch/oxt_handler.hxx (original)
+++ openoffice/trunk/main/framework/inc/dispatch/oxt_handler.hxx Tue Apr 29 19:05:05 2014
@@ -139,7 +139,7 @@ class Oxt_Handler  :   // interfaces
                     ,   public  css::frame::XNotifyingDispatch // => XDispatch
                     ,   public  css::document::XExtendedFilterDetection
                         // baseclasses
-                        // Order is neccessary for right initialization!
+                        // Order is necessary for right initialization!
                     ,   private ThreadHelpBase
                     ,   public  ::cppu::OWeakObject
 {

Modified: openoffice/trunk/main/framework/inc/dispatch/popupmenudispatcher.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/dispatch/popupmenudispatcher.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/inc/dispatch/popupmenudispatcher.hxx (original)
+++ openoffice/trunk/main/framework/inc/dispatch/popupmenudispatcher.hxx Tue Apr 29 19:05:05 2014
@@ -121,7 +121,7 @@ class PopupMenuDispatcher :   // interfa
 								public css::frame::XFrameActionListener	,
                                 public css::lang::XInitialization       ,
 								// baseclasses
-								// Order is neccessary for right initialization!
+								// Order is necessary for right initialization!
 								public ThreadHelpBase					,
 								public cppu::OWeakObject
 {

Modified: openoffice/trunk/main/framework/inc/dispatch/selfdispatcher.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/dispatch/selfdispatcher.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/inc/dispatch/selfdispatcher.hxx (original)
+++ openoffice/trunk/main/framework/inc/dispatch/selfdispatcher.hxx Tue Apr 29 19:05:05 2014
@@ -72,7 +72,7 @@ namespace framework{
     @threadsafe     yes
 *//*-*************************************************************************************************************/
 class SelfDispatcher   :   // -interfaces  ... are supported by our BaseDispatcher!
-                           // -baseclasses ... order is neccessary for right initialization!
+                           // -baseclasses ... order is necessary for right initialization!
                            public BaseDispatcher
 {
 	//-------------------------------------------------------------------------------------------------------------

Modified: openoffice/trunk/main/framework/inc/dispatch/servicehandler.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/dispatch/servicehandler.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/inc/dispatch/servicehandler.hxx (original)
+++ openoffice/trunk/main/framework/inc/dispatch/servicehandler.hxx Tue Apr 29 19:05:05 2014
@@ -70,10 +70,10 @@ namespace framework{
 /**
     @short          protocol handler for "service:*" URLs
     @descr          It's a special dispatch/provider object which is registered for such URL pattern and will
-                    be automaticly used by the framework dispatch mechanism if such URL occured.
+                    be automatically used by the framework dispatch mechanism if such URL occurred.
                     His job is to create any registered uno components which must be coded inside
                     dispatched URL (may with some optional given parameters). After that such created
-                    service must be hold his self alive. Such mechanism can be usefull for UI components
+                    service must be hold his self alive. Such mechanism can be useful for UI components
                     (e.g. Dialogs, Wizards) only.
 
     @base           ThreadHelpBase
@@ -91,7 +91,7 @@ class ServiceHandler : // interfaces
                        public  css::frame::XDispatchProvider ,
                        public  css::frame::XNotifyingDispatch, // => XDispatch
                        // baseclasses
-                       // Order is neccessary for right initialization!
+                       // Order is necessary for right initialization!
                        private ThreadHelpBase                ,
                        public  cppu::OWeakObject
 {

Modified: openoffice/trunk/main/framework/inc/dispatch/startmoduledispatcher.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/dispatch/startmoduledispatcher.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/inc/dispatch/startmoduledispatcher.hxx (original)
+++ openoffice/trunk/main/framework/inc/dispatch/startmoduledispatcher.hxx Tue Apr 29 19:05:05 2014
@@ -64,7 +64,7 @@ namespace framework{
 class StartModuleDispatcher : public css::lang::XTypeProvider
                             , public css::frame::XNotifyingDispatch             // => XDispatch
                             , public css::frame::XDispatchInformationProvider
-                            // baseclasses ... order is neccessary for right initialization!
+                            // baseclasses ... order is necessary for right initialization!
                             , private ThreadHelpBase
                             , public  ::cppu::OWeakObject
 {
@@ -180,7 +180,7 @@ class StartModuleDispatcher : public css
                     directly used as css::frame::DispatchResultState value.
 
             @param  aResult
-                    not used yet realy ...
+                    not used yet really ...
          */
         void implts_notifyResultListener(const css::uno::Reference< css::frame::XDispatchResultListener >& xListener,
                                                sal_Int16                                                   nState   ,

Modified: openoffice/trunk/main/framework/inc/dispatch/systemexec.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/dispatch/systemexec.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/inc/dispatch/systemexec.hxx (original)
+++ openoffice/trunk/main/framework/inc/dispatch/systemexec.hxx Tue Apr 29 19:05:05 2014
@@ -70,7 +70,7 @@ namespace framework{
 /**
     @short          protocol handler for "systemexec:*" URLs
     @descr          It's a special dispatch/provider object which is registered for such URL pattern and will
-                    be automaticly used by the framework dispatch mechanism if such URL occured.
+                    be automatically used by the framework dispatch mechanism if such URL occurred.
                     It forwards all URL's to the underlying operating system.
                     So it would e.g. be possible to open HTML files outside the office within a web browser.
 
@@ -87,7 +87,7 @@ class SystemExec : // interfaces
                        public  css::frame::XDispatchProvider ,
                        public  css::frame::XNotifyingDispatch, // => XDispatch
                        // baseclasses
-                       // Order is neccessary for right initialization!
+                       // Order is necessary for right initialization!
                        private ThreadHelpBase                ,
                        public  cppu::OWeakObject
 {

Modified: openoffice/trunk/main/framework/inc/framework/addonsoptions.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/framework/addonsoptions.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/inc/framework/addonsoptions.hxx (original)
+++ openoffice/trunk/main/framework/inc/framework/addonsoptions.hxx Tue Apr 29 19:05:05 2014
@@ -41,7 +41,7 @@
 
 /*-************************************************************************************************************//**
     @descr          The method GetAddonsMenu() returns a list of property values.
-                    Use follow defines to seperate values by names.
+                    Use follow defines to separate values by names.
 *//*-*************************************************************************************************************/
 #define ADDONSMENUITEM_STRING_URL                       "URL"
 #define ADDONSMENUITEM_STRING_TITLE                     "Title"
@@ -128,7 +128,7 @@ typedef ::std::vector< MergeStatusbarIns
 /*-************************************************************************************************************//**
     @short          forward declaration to our private date container implementation
     @descr          We use these class as internal member to support small memory requirements.
-                    You can create the container if it is neccessary. The class which use these mechanism
+                    You can create the container if it is necessary. The class which use these mechanism
                     is faster and smaller then a complete implementation!
 *//*-*************************************************************************************************************/
 

Modified: openoffice/trunk/main/framework/inc/framework/framelistanalyzer.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/framework/framelistanalyzer.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/inc/framework/framelistanalyzer.hxx (original)
+++ openoffice/trunk/main/framework/inc/framework/framelistanalyzer.hxx Tue Apr 29 19:05:05 2014
@@ -46,7 +46,7 @@ namespace framework{
 /** analyze and split the current available frame list of a given frames supplier
     into different parts.
 
-    These analyzed informations can be used e.g. to decide if it's neccessary
+    These analyzed informations can be used e.g. to decide if it's necessary
     to switch into the backing mode, close the current active frame only or
     exit the whole application explicitly or implicitly.
  */
@@ -93,13 +93,13 @@ class FWE_DLLPUBLIC FrameListAnalyzer
         ::com::sun::star::uno::Sequence< ::com::sun::star::uno::Reference< ::com::sun::star::frame::XFrame > > m_lModelFrames;
 
         /** contains all frames, which does not contain the same model like the reference frame.
-            Filling of it can't be supressed by m_eDetectMode.
+            Filling of it can't be suppressed by m_eDetectMode.
             The reference frame is never part of this list!
             All frames inside this list are visible ones. */
         ::com::sun::star::uno::Sequence< ::com::sun::star::uno::Reference< ::com::sun::star::frame::XFrame > > m_lOtherVisibleFrames;
 
         /** contains all frames, which does not contain the same model like the reference frame.
-            Filling of it can't be supressed by m_eDetectMode.
+            Filling of it can't be suppressed by m_eDetectMode.
             The reference frame is never part of this list!
             All frames inside this list are hidden ones. */
         ::com::sun::star::uno::Sequence< ::com::sun::star::uno::Reference< ::com::sun::star::frame::XFrame > > m_lOtherHiddenFrames;

Modified: openoffice/trunk/main/framework/inc/framework/preventduplicateinteraction.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/framework/preventduplicateinteraction.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/inc/framework/preventduplicateinteraction.hxx (original)
+++ openoffice/trunk/main/framework/inc/framework/preventduplicateinteraction.hxx Tue Apr 29 19:05:05 2014
@@ -189,7 +189,7 @@ class FWE_DLLPUBLIC PreventDuplicateInte
             @param      xSMGR
                             uno service manager for creating services internaly
 
-            @threadsafe not neccessary
+            @threadsafe not necessary
         */
         PreventDuplicateInteraction(const css::uno::Reference< css::lang::XMultiServiceFactory >& xSMGR);
 
@@ -225,10 +225,10 @@ class FWE_DLLPUBLIC PreventDuplicateInte
             @short      add a new interaction to the list of interactions, which
                         must be handled by this helper.
 
-            @descr      This method must be called immediatly after a new instance of this helper was
+            @descr      This method must be called immediately after a new instance of this helper was
                         created. Without such list of InteractionRules, this instances does nothing!
                         On the other side there is no possibility to remove rules.
-                        So the same instance cant be used within different transactions.
+                        So the same instance can't be used within different transactions.
                         It's a OneWay-object .-)
 
             @param      aInteractionInfo

Modified: openoffice/trunk/main/framework/inc/general.h
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/general.h?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/inc/general.h (original)
+++ openoffice/trunk/main/framework/inc/general.h Tue Apr 29 19:05:05 2014
@@ -29,7 +29,7 @@
 
 #include <macros/generic.hxx>
 
-/* Normaly XInterface isnt used here ...
+/* Normaly XInterface isn't used here ...
    But we need it to be able to define namespace alias css to anything related to ::com::sun::star
    :-) */
 #include <com/sun/star/uno/XInterface.hpp>

Modified: openoffice/trunk/main/framework/inc/helper/fixeddocumentproperties.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/helper/fixeddocumentproperties.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/inc/helper/fixeddocumentproperties.hxx (original)
+++ openoffice/trunk/main/framework/inc/helper/fixeddocumentproperties.hxx Tue Apr 29 19:05:05 2014
@@ -37,15 +37,15 @@ struct FixedDocumentProperties
 	sal_Bool										m_bAutoloadEnabled			;	/// Automatic reload enabled/disabled ?
 	sal_Int32										m_nAutoloadSecs     		;	/// Time cycle for automatic reload
 	::rtl::OUString									m_sAutoloadURL      		;	/// URL for automatic reload
-	::rtl::OUString									m_sBlindCopiesTo    		;	/// Adress for BCC
-	::rtl::OUString									m_sCopiesTo           		;	///	Adress CC
+	::rtl::OUString									m_sBlindCopiesTo    		;	/// Address for BCC
+	::rtl::OUString									m_sCopiesTo           		;	///	Address CC
 	com::sun::star::util::DateTime					m_aCreationDate     		;	/// Time and date of document creation
 	::rtl::OUString									m_sDefaultTarget    		;	/// Name of default target
 	::rtl::OUString									m_sDescription      		;	/// Short description and comments
 	sal_Int16										m_nEditingCycles			;	/// Document number
 	sal_Int32										m_nEditingDuration			;	/// Duration since last edit
 	com::sun::star::uno::Sequence< sal_Int8 >		m_seqExtraData				;	/// Buffer of bytes for some extra data
-	::rtl::OUString									m_sInReplyTo				;	/// Adress for reply to ...
+	::rtl::OUString									m_sInReplyTo				;	/// Address for reply to ...
 	sal_Bool										m_bIsEncrypted				;	/// Document is en/decrypted
 	::rtl::OUString									m_sKeywords					;	/// Some keywords
 	::rtl::OUString									m_sMIMEType					;	/// MIME-type of document
@@ -60,7 +60,7 @@ struct FixedDocumentProperties
 	sal_Bool										m_bQueryTemplate			;	/// Search for template ?
 	::rtl::OUString									m_sRecipient				;	/// Name of recipient
 	::rtl::OUString									m_sReferences				;	/// Some references to other things
-	::rtl::OUString									m_sReplyTo					;	/// Adress to reply
+	::rtl::OUString									m_sReplyTo					;	/// Address to reply
 	sal_Bool										m_bSaveGraphicsCompressed	;	/// Compressed/non compressed graphics
 	sal_Bool										m_bSaveOriginalGraphics		;	/// Include graphics
 	sal_Bool										m_bSaveVersionOnClose		;	/// Save version on close of document ?

Modified: openoffice/trunk/main/framework/inc/helper/ocomponentaccess.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/helper/ocomponentaccess.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/inc/helper/ocomponentenumeration.hxx (original)
+++ openoffice/trunk/main/framework/inc/helper/ocomponentenumeration.hxx Tue Apr 29 19:05:05 2014
@@ -67,7 +67,7 @@ namespace framework{
 	@short			implement a helper for a oneway enumeration of components
 	@descr			You can step during this list only for one time! Its a snapshot.
 					Don't forget to release the reference. You are the owner of an instance of this implementation.
-					You cant use this as a baseclass. Please use it as a dynamical object for return.
+					You can't use this as a baseclass. Please use it as a dynamical object for return.
 
 	@implements		XInterface
 					XTypeProvider

Modified: openoffice/trunk/main/framework/inc/helper/oframes.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/helper/oframes.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/inc/helper/oframes.hxx (original)
+++ openoffice/trunk/main/framework/inc/helper/oframes.hxx Tue Apr 29 19:05:05 2014
@@ -83,7 +83,7 @@ namespace framework{
 	@devstatus		deprecated
 *//*-*************************************************************************************************************/
 
-class OFrames   :   private ThreadHelpBase      ,   // Must be the first of baseclasses - Is neccessary for right initialization of objects!
+class OFrames   :   private ThreadHelpBase      ,   // Must be the first of baseclasses - Is necessary for right initialization of objects!
 					public ::cppu::WeakImplHelper1< ::com::sun::star::frame::XFrames >
 {
 	//-------------------------------------------------------------------------------------------------------------

Modified: openoffice/trunk/main/framework/inc/helper/otasksenumeration.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/helper/otasksenumeration.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/inc/helper/otasksenumeration.hxx (original)
+++ openoffice/trunk/main/framework/inc/helper/otasksenumeration.hxx Tue Apr 29 19:05:05 2014
@@ -68,7 +68,7 @@ namespace framework{
 	@short			implement a helper for a oneway enumeration of tasks
 	@descr			You can step during this list only for one time! Its a snapshot.
 					Don't forget to release the reference. You are the owner of an instance of this implementation.
-					You cant use this as a baseclass. Please use it as a dynamical object for return.
+					You can't use this as a baseclass. Please use it as a dynamical object for return.
 
 	@implements		XInterface
 					XTypeProvider

Modified: openoffice/trunk/main/framework/inc/helper/persistentwindowstate.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/helper/persistentwindowstate.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/inc/helper/persistentwindowstate.hxx (original)
+++ openoffice/trunk/main/framework/inc/helper/persistentwindowstate.hxx Tue Apr 29 19:05:05 2014
@@ -87,7 +87,7 @@ class PersistentWindowState :   // inter
                                 public css::lang::XTypeProvider,
                                 public css::lang::XInitialization,
                                 public css::frame::XFrameActionListener, // => XEventListener
-                                // baseclasses (order neccessary for right initialization!)
+                                // baseclasses (order necessary for right initialization!)
                                 private ThreadHelpBase,
                                 public  ::cppu::OWeakObject
 {
@@ -177,7 +177,7 @@ class PersistentWindowState :   // inter
 
             @param  xWindow
                     must point to the container window of the frame.
-                    We use it VCL part here - because the toolkit doesnt
+                    We use it VCL part here - because the toolkit doesn't
                     provide the right functionality!
 
             @return [string]
@@ -207,7 +207,7 @@ class PersistentWindowState :   // inter
 
             @param  xWindow
                     must point to the container window of the frame.
-                    We use it VCL part here - because the toolkit doesnt
+                    We use it VCL part here - because the toolkit doesn't
                     provide the right functionality!
 
             @param  sWindowState

Modified: openoffice/trunk/main/framework/inc/helper/statusindicator.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/helper/statusindicator.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/inc/helper/statusindicator.hxx (original)
+++ openoffice/trunk/main/framework/inc/helper/statusindicator.hxx Tue Apr 29 19:05:05 2014
@@ -70,7 +70,7 @@ namespace framework{
 */
 class StatusIndicator : public  css::lang::XTypeProvider
                       , public  css::task::XStatusIndicator
-                      , private ThreadHelpBase                  // Order of baseclasses is neccessary for right initializaton!
+                      , private ThreadHelpBase                  // Order of baseclasses is necessary for right initializaton!
                       , public  ::cppu::OWeakObject             // => XInterface
 {
     //-------------------------------------------

Modified: openoffice/trunk/main/framework/inc/helper/statusindicatorfactory.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/helper/statusindicatorfactory.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/inc/helper/statusindicatorfactory.hxx (original)
+++ openoffice/trunk/main/framework/inc/helper/statusindicatorfactory.hxx Tue Apr 29 19:05:05 2014
@@ -289,7 +289,7 @@ class StatusIndicatorFactory : public  c
                     if it's allowed to do so.
 
 
-            @descr  By default we show the parent window automaticly
+            @descr  By default we show the parent window automatically
                     if this progress is used.
                     If that isn't a valid operation, the user of this
                     progress can suppress this feature by initializaing

Modified: openoffice/trunk/main/framework/inc/helper/tagwindowasmodified.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/helper/tagwindowasmodified.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/inc/helper/tagwindowasmodified.hxx (original)
+++ openoffice/trunk/main/framework/inc/helper/tagwindowasmodified.hxx Tue Apr 29 19:05:05 2014
@@ -65,7 +65,7 @@ namespace framework{
 
 /*-************************************************************************************************************//**
     @short          listen for modify events on model and tag frame container window so it can react accordingly
-    @descr          Used e.g. by our MAC port where such state is shown seperately on some controls of the
+    @descr          Used e.g. by our MAC port where such state is shown separately on some controls of the
                     title bar.
 
     @base           ThreadHelpBase
@@ -83,7 +83,7 @@ class TagWindowAsModified :   // interfa
                               public css::lang::XInitialization,
                               public css::frame::XFrameActionListener, // => XEventListener
                               public css::util::XModifyListener,       // => XEventListener
-                              // baseclasses (order neccessary for right initialization!)
+                              // baseclasses (order necessary for right initialization!)
                               private ThreadHelpBase,
                               public  ::cppu::OWeakObject
 {

Modified: openoffice/trunk/main/framework/inc/helper/titlebarupdate.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/helper/titlebarupdate.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/inc/helper/titlebarupdate.hxx (original)
+++ openoffice/trunk/main/framework/inc/helper/titlebarupdate.hxx Tue Apr 29 19:05:05 2014
@@ -121,7 +121,7 @@ class TitleBarUpdate : // interfaces
                      , public css::lang::XInitialization
                      , public css::frame::XTitleChangeListener // => XEventListener
                      , public css::frame::XFrameActionListener // => XEventListener
-                       // baseclasses (order neccessary for right initialization!)
+                       // baseclasses (order necessary for right initialization!)
                      , private ThreadHelpBase
                      , public  ::cppu::OWeakObject
 {
@@ -213,7 +213,7 @@ class TitleBarUpdate : // interfaces
         //____________________________
         /** @short  set a new icon and title on the title bar of our connected frame window.
 
-            @descr  It does not check if an update is realy needed. That has to be done outside.
+            @descr  It does not check if an update is really needed. That has to be done outside.
                     It retrieves all needed informations and update the title bar - nothing less -
                     nothing more.
          */

Modified: openoffice/trunk/main/framework/inc/helper/vclstatusindicator.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/helper/vclstatusindicator.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/inc/helper/vclstatusindicator.hxx (original)
+++ openoffice/trunk/main/framework/inc/helper/vclstatusindicator.hxx Tue Apr 29 19:05:05 2014
@@ -69,7 +69,7 @@ class VCLStatusIndicator : public  css::
         
         /** shows the progress.
         
-            @attention  This member isnt synchronized using our own mutex!
+            @attention  This member isn't synchronized using our own mutex!
                         Its guarded by the solarmutex only. Otherwhise
                         we have to lock two of them, which can force a deadlock ...
             */

Modified: openoffice/trunk/main/framework/inc/interaction/quietinteraction.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/interaction/quietinteraction.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/inc/interaction/quietinteraction.hxx (original)
+++ openoffice/trunk/main/framework/inc/interaction/quietinteraction.hxx Tue Apr 29 19:05:05 2014
@@ -60,7 +60,7 @@ namespace framework{
 
 /**
     @short      handle interactions non visible
-    @descr      Sometimes it's neccessary to use a non visible interaction handler.
+    @descr      Sometimes it's necessary to use a non visible interaction handler.
                 He can't do anything, which a visible one can handle.
                 But it can be used to intercept problems e.g. during loading of documents.
 
@@ -98,7 +98,7 @@ class QuietInteraction : public  css::la
             @interface  XInteractionHandler
             @short      called from outside to handle a problem
             @descr      The only interaction we can handle here is to
-                        decide which of two ambigous filters should be realy used.
+                        decide which of two ambigous filters should be really used.
                         We use the user selected one every time.
                         All other request will be aborted and can break the code,
                         which use this interaction handler.
@@ -121,7 +121,7 @@ class QuietInteraction : public  css::la
             @short      ctor to guarantee right initialized instances of this class
             @descr      -
 
-            @threadsafe not neccessary
+            @threadsafe not necessary
         */
         QuietInteraction();
 
@@ -130,7 +130,7 @@ class QuietInteraction : public  css::la
             @short      return the handled interaction request
             @descr      We saved any getted interaction request internaly.
                         May the outside user of this class is interessted
-                        on that. Especialy we gotted an unknown interaction
+                        on that. Especially we gotted an unknown interaction
                         and aborted it hard.
 
             @return     [com.sun.star.uno.Any]

Modified: openoffice/trunk/main/framework/inc/jobs/configaccess.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/jobs/configaccess.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/inc/jobs/configaccess.hxx (original)
+++ openoffice/trunk/main/framework/inc/jobs/configaccess.hxx Tue Apr 29 19:05:05 2014
@@ -80,7 +80,7 @@ class FWI_DLLPUBLIC ConfigAccess : publi
 
         /**
             reference to the uno service manager
-            It's neccessary to instanciate own needed services.
+            It's necessary to instanciate own needed services.
          */
         css::uno::Reference< css::lang::XMultiServiceFactory > m_xSMGR;
 

Modified: openoffice/trunk/main/framework/inc/jobs/helponstartup.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/jobs/helponstartup.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/inc/jobs/helponstartup.hxx (original)
+++ openoffice/trunk/main/framework/inc/jobs/helponstartup.hxx Tue Apr 29 19:05:05 2014
@@ -111,7 +111,7 @@ class HelpOnStartup : private ThreadHelp
         /** @short  does nothing real ...
 
             @descr  But it should exists as virtual function,
-                    so this class cant make trouble
+                    so this class can't make trouble
                     related to inline/symbols etcpp.!
          */
         virtual ~HelpOnStartup();
@@ -158,11 +158,11 @@ class HelpOnStartup : private ThreadHelp
         /** @short  tries to locate the open help module and return
                     the url of the currently shown help content.
 
-            @descr  It returns an empty string, if the help isnt still
+            @descr  It returns an empty string, if the help isn't still
                     open at calling time.
 
             @return The URL of the current shown help content;
-                    or an empty value if the help isnt still open.
+                    or an empty value if the help isn't still open.
          */
         ::rtl::OUString its_getCurrentHelpURL();
 
@@ -180,7 +180,7 @@ class HelpOnStartup : private ThreadHelp
         ::sal_Bool its_isHelpUrlADefaultOne(const ::rtl::OUString& sHelpURL);
 
         //---------------------------------------
-        /** @short  checks, if the help module should be shown automaticly for the
+        /** @short  checks, if the help module should be shown automatically for the
                     currently opened office module.
 
             @descr  This value is readed from the module configuration.

Modified: openoffice/trunk/main/framework/inc/jobs/job.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/jobs/job.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/inc/jobs/job.hxx (original)
+++ openoffice/trunk/main/framework/inc/jobs/job.hxx Tue Apr 29 19:05:05 2014
@@ -100,7 +100,7 @@ class Job : public  css::lang::XTypeProv
     private:
 
         /**
-            hold all neccessary informations about this job.
+            hold all necessary informations about this job.
             It can be used for both modes: with and without configuration.
          */
         JobData m_aJobCfg;
@@ -126,7 +126,7 @@ class Job : public  css::lang::XTypeProv
             We use it too, to listen for closing events of this ressource.
 
             Please note: If m_xFrame is set - m_xModel should be NULL.
-            Only one environment can be supported realy.
+            Only one environment can be supported really.
          */
         css::uno::Reference< css::frame::XFrame > m_xFrame;
 
@@ -136,13 +136,13 @@ class Job : public  css::lang::XTypeProv
             We use it too, to listen for closing events of this ressource.
 
             Please note: If m_xModel is set - m_xFrame should be NULL.
-            Only one environment can be supported realy.
+            Only one environment can be supported really.
          */
         css::uno::Reference< css::frame::XModel > m_xModel;
 
         /**
             We are registered at this instance to listen for office shutdown events.
-            It's neccessary supress it (if possible) or to react in the right way.
+            It's necessary suppress it (if possible) or to react in the right way.
          */
         css::uno::Reference< css::frame::XDesktop > m_xDesktop;
 
@@ -163,7 +163,7 @@ class Job : public  css::lang::XTypeProv
 
         /**
             Holds the state, if we are listen for desktop/frame or model closing events or not.
-            The used references are not realy enough to detect a valid listener connection.
+            The used references are not really enough to detect a valid listener connection.
             Thats why we use this additional information here too.
          */
         sal_Bool m_bListenOnDesktop;
@@ -182,7 +182,7 @@ class Job : public  css::lang::XTypeProv
             indicates in which state the internal job currently exist.
 
             We can use this information to throw any suitable veto exception
-            to prevent the environment against dieing or supress superflous dispose()
+            to prevent the environment against dieing or suppress superflous dispose()
             calls at the job.
          */
         ERunState m_eRunState;

Modified: openoffice/trunk/main/framework/inc/jobs/jobconst.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/jobs/jobconst.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/inc/jobs/jobconst.hxx (original)
+++ openoffice/trunk/main/framework/inc/jobs/jobconst.hxx Tue Apr 29 19:05:05 2014
@@ -53,7 +53,7 @@ namespace framework{
 
     @descr  The protocol between job executor/dispatch and jobs is fix and well defined.
             But why every implemented job should write such constant values directly into
-            it's code. Typos can occure or code will be changed by new developers ...
+            it's code. Typos can occur or code will be changed by new developers ...
             Shared set of constant values can help to improve the mentainance of this code.
  */
 class FWI_DLLPUBLIC JobConst

Modified: openoffice/trunk/main/framework/inc/jobs/jobdata.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/jobs/jobdata.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/inc/jobs/jobdata.hxx (original)
+++ openoffice/trunk/main/framework/inc/jobs/jobdata.hxx Tue Apr 29 19:05:05 2014
@@ -57,7 +57,7 @@ namespace framework{
 // definitions
 
 /**
-    @short  holds all neccessary informations about a job and
+    @short  holds all necessary informations about a job and
             handle it's configuration (if any exist!)
     @descr  It can be used rom different use cases as a container
             (or proxy) for all config data of a registered job.
@@ -145,8 +145,8 @@ class JobData : private ThreadHelpBase
         /** Some jobs can be registered to "logical events", which are generated on demand if another document event
             occures. E.g. "onDocumentOpened" in case "OnNew" or "OnLoad" was notified to the JobExecutor instance.
             And normaly the original event is transported as parameter set to the executed job. But then such job
-            cant differ between e.g. "OnNew" and "onDocumentOpened".
-            That's why we must know, for which type of event the job was realy triggered .-)
+            can't differ between e.g. "OnNew" and "onDocumentOpened".
+            That's why we must know, for which type of event the job was really triggered .-)
         
             The information "sDocEvent" from this struct must be set on the member JobData::m_sEvent from outside
             user of such Jobdata structure.
@@ -198,7 +198,7 @@ class JobData : private ThreadHelpBase
         /**
             the alias name of this job.
             Is used as entry of configuration set for job registration, to find all
-            neccessary properties of it..
+            necessary properties of it..
          */
         ::rtl::OUString m_sAlias;
 
@@ -232,7 +232,7 @@ class JobData : private ThreadHelpBase
         css::uno::Sequence< css::beans::NamedValue > m_lArguments;
 
         /**
-            after a job was sucessfully executed (by any outside code using our
+            after a job was successfully executed (by any outside code using our
             informations) it can return a result. This member make it part of this
             container too. So it can be used for further things.
             We use it also to update our internal state and the configuration

Modified: openoffice/trunk/main/framework/inc/jobs/jobexecutor.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/jobs/jobexecutor.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/inc/jobs/jobexecutor.hxx (original)
+++ openoffice/trunk/main/framework/inc/jobs/jobexecutor.hxx Tue Apr 29 19:05:05 2014
@@ -64,7 +64,7 @@ namespace framework{
     @short  implements a job executor, which can be triggered from any code
     @descr  It uses the given trigger event to locate any registered job service
             inside the configuration and execute it. Of course it controls the
-            liftime of such jobs too.
+            lifetime of such jobs too.
  */
 class JobExecutor : public  css::lang::XTypeProvider
                   , public  css::lang::XServiceInfo

Modified: openoffice/trunk/main/framework/inc/jobs/jobresult.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/jobs/jobresult.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/inc/jobs/jobresult.hxx (original)
+++ openoffice/trunk/main/framework/inc/jobs/jobresult.hxx Tue Apr 29 19:05:05 2014
@@ -92,7 +92,7 @@ class JobResult : private ThreadHelpBase
 
         /**
             an user of us must know, which (possible) parts of
-            a "pure result" was realy set by an executed job.
+            a "pure result" was really set by an executed job.
             Means which other members of this class are valid.
             This mask can be used to find it out.
          */

Modified: openoffice/trunk/main/framework/inc/jobs/joburl.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/jobs/joburl.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/inc/jobs/joburl.hxx (original)
+++ openoffice/trunk/main/framework/inc/jobs/joburl.hxx Tue Apr 29 19:05:05 2014
@@ -67,7 +67,7 @@ namespace framework{
     @short  can be used to parse, validate and work with job URL's
     @descr  Job URLs are specified by the following syntax:
                 vnd.sun.star.job:{[event=<name>]|[alias=<name>]|[service=<name>]}
-            This class can analyze this structure and seperate it into his different parts.
+            This class can analyze this structure and separate it into his different parts.
             After doing that these parts are accessible by the methods of this class.
  */
 class JobURL : private ThreadHelpBase

Modified: openoffice/trunk/main/framework/inc/jobs/shelljob.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/jobs/shelljob.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/inc/jobs/shelljob.hxx (original)
+++ openoffice/trunk/main/framework/inc/jobs/shelljob.hxx Tue Apr 29 19:05:05 2014
@@ -92,7 +92,7 @@ class ShellJob : private ThreadHelpBase
         /** @short  does nothing real ...
 
             @descr  But it should exists as virtual function,
-                    so this class cant make trouble
+                    so this class can't make trouble
                     related to inline/symbols etcpp.!
          */
         virtual ~ShellJob();

Modified: openoffice/trunk/main/framework/inc/loadstate.h
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/loadstate.h?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/inc/loadstate.h (original)
+++ openoffice/trunk/main/framework/inc/loadstate.h Tue Apr 29 19:05:05 2014
@@ -41,12 +41,12 @@ namespace framework{
 /**
     These enum values specify all possible results of a load request.
     It doesn't matter, if this load operation used dispatch() or loadComponentFromURL().
-    The meaning is everytime the same.
+    The meaning is every time the same.
  */
 enum ELoadState
 {
     E_UNSPECIFIED   =   0,  // indicates the operation was not already started
-    E_SUCCESS       =   1,  // the load request was successfull
+    E_SUCCESS       =   1,  // the load request was successful
     E_IOERROR       =   2,  // there was an io error internaly
     E_INTERACTION   =   3,  // there was an interaction, which couldn't be handled (doesn't include IO interactions => see E_IOERROR before)
     E_FAILED        =   4   // for unknown or unspecified errors

Modified: openoffice/trunk/main/framework/inc/macros/debug/assertion.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/macros/debug/assertion.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/inc/macros/debug/assertion.hxx (original)
+++ openoffice/trunk/main/framework/inc/macros/debug/assertion.hxx Tue Apr 29 19:05:05 2014
@@ -195,7 +195,7 @@
 		LOG_EXCEPTION( SMETHOD, SOWNMESSAGE, SEXCEPTIONMESSAGE )
 
 		Show some exception info by using current set output mode by define LOGTYPE!
-		We use a seperated scope {} do protect us against multiple variable definitions.
+		We use a separated scope {} do protect us against multiple variable definitions.
 	_____________________________________________________________________________________________________________*/
 
 	#define	LOG_EXCEPTION( SMETHOD, SOWNMESSAGE, SEXCEPTIONMESSAGE )											\

Modified: openoffice/trunk/main/framework/inc/macros/debug/event.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/macros/debug/event.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/inc/macros/debug/event.hxx (original)
+++ openoffice/trunk/main/framework/inc/macros/debug/event.hxx Tue Apr 29 19:05:05 2014
@@ -52,7 +52,7 @@
 	/*_____________________________________________________________________________________________________________
 		LOG_FRAMEACTIONEVENT( SFRAMETYPE, SFRAMENAME, AFRAMEACTION )
 
-		Use this macro to print debug informations about sending of events to listener for controling right order.
+		Use this macro to print debug informations about sending of events to listener for controlling right order.
 		( Use new scope in macro to declare sBuffer more then on time in same "parentscope"! )
 	_____________________________________________________________________________________________________________*/
 

Modified: openoffice/trunk/main/framework/inc/macros/debug/filterdbg.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/macros/debug/filterdbg.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/inc/macros/debug/filterdbg.hxx (original)
+++ openoffice/trunk/main/framework/inc/macros/debug/filterdbg.hxx Tue Apr 29 19:05:05 2014
@@ -26,7 +26,7 @@
 
 //*************************************************************************************************************
 //  special macros for time measures
-//  1) LOGFILE_FILTERDBG                  used it to define log file for this operations (default will be set automaticly)
+//  1) LOGFILE_FILTERDBG                  used it to define log file for this operations (default will be set automatically)
 //  4) LOG_FILTERDBG                      write debug info to log file
 //*************************************************************************************************************
 

Modified: openoffice/trunk/main/framework/inc/macros/debug/memorymeasure.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/macros/debug/memorymeasure.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/inc/macros/debug/memorymeasure.hxx (original)
+++ openoffice/trunk/main/framework/inc/macros/debug/memorymeasure.hxx Tue Apr 29 19:05:05 2014
@@ -26,7 +26,7 @@
 
 //*************************************************************************************************************
 //  special macros for time measures
-//  1) LOGFILE_MEMORYMEASURE                  used it to define log file for this operations (default will be set automaticly)
+//  1) LOGFILE_MEMORYMEASURE                  used it to define log file for this operations (default will be set automatically)
 //  2) MAKE_MEMORY_SNAPSHOT                   make snapshot of currently set memory informations of OS
 //  3) LOG_MEMORYMEASURE                      write measured time to logfile
 //*************************************************************************************************************

Modified: openoffice/trunk/main/framework/inc/macros/debug/timemeasure.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/macros/debug/timemeasure.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/inc/macros/debug/timemeasure.hxx (original)
+++ openoffice/trunk/main/framework/inc/macros/debug/timemeasure.hxx Tue Apr 29 19:05:05 2014
@@ -26,7 +26,7 @@
 
 //*************************************************************************************************************
 //  special macros for time measures
-//  1) LOGFILE_TIMEMEASURE                  used it to define log file for this operations (default will be set automaticly)
+//  1) LOGFILE_TIMEMEASURE                  used it to define log file for this operations (default will be set automatically)
 //  2) START_TIMEMEASURE                    start new measure by using given variable names
 //  3) START_TIMEMEASURE                    stop current measure by using given variable names and return time
 //  4) LOG_TIMEMEASURE                      write measured time to logfile

Modified: openoffice/trunk/main/framework/inc/macros/xserviceinfo.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/macros/xserviceinfo.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/inc/macros/xserviceinfo.hxx (original)
+++ openoffice/trunk/main/framework/inc/macros/xserviceinfo.hxx Tue Apr 29 19:05:05 2014
@@ -66,7 +66,7 @@ namespace framework{
     1)  DECLARE_XSERVICEINFO                                                                                => use it to declare XServiceInfo in your header
     2)  DEFINE_XSERVICEINFO_MULTISERVICE( CLASS, XINTERFACECAST, SERVICENAME, IMPLEMENTATIONNAME )          => use it to define XServiceInfo for multi service mode
     3)  DEFINE_XSERVICEINFO_ONEINSTANCESERVICE( CLASS, XINTERFACECAST, SERVICENAME, IMPLEMENTATIONNAME )    => use it to define XServiceInfo for one instance service mode
-    4)  DEFINE_INIT_SERVICE( CLASS )                                                                        => use it to implement your own impl_initService() method, which is neccessary for initializeing object by using his own reference!
+    4)  DEFINE_INIT_SERVICE( CLASS )                                                                        => use it to implement your own impl_initService() method, which is necessary for initializeing object by using his own reference!
 
 _________________________________________________________________________________________________________________*/
 

Modified: openoffice/trunk/main/framework/inc/macros/xtypeprovider.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/macros/xtypeprovider.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/inc/macros/xtypeprovider.hxx (original)
+++ openoffice/trunk/main/framework/inc/macros/xtypeprovider.hxx Tue Apr 29 19:05:05 2014
@@ -314,8 +314,8 @@ ________________________________________
 //	implementation of XTypeProvider
 //*****************************************************************************************************************
 //	implementation of XTypeProvider without additional interface for getTypes()
-//	XTypeProvider is used as the only one interface automaticly.
-//	Following defines don't use XTypeProvider automaticly!!!!
+//	XTypeProvider is used as the only one interface automatically.
+//	Following defines don't use XTypeProvider automatically!!!!
 #define DEFINE_XTYPEPROVIDER_0( CLASS )																				\
 	PRIVATE_DEFINE_XTYPEPROVIDER_PURE(	CLASS )
 

Modified: openoffice/trunk/main/framework/inc/protocols.h
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/protocols.h?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/inc/protocols.h (original)
+++ openoffice/trunk/main/framework/inc/protocols.h Tue Apr 29 19:05:05 2014
@@ -41,7 +41,7 @@ namespace framework{
 //_______________________________________________________________________
 /**
     some protocols must be checked during loading or dispatching URLs manually
-    It can be neccessary to decide, if a URL represent a non visible content or
+    It can be necessary to decide, if a URL represent a non visible content or
     a real visible component.
  */
 

Modified: openoffice/trunk/main/framework/inc/queries.h
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/queries.h?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/inc/queries.h (original)
+++ openoffice/trunk/main/framework/inc/queries.h Tue Apr 29 19:05:05 2014
@@ -359,7 +359,7 @@ class QueryAnalyzer
 
         //---------------------------------------------------------------------------------------------------------
         // access to additional parameter values
-        // Methods return default of realy set values!
+        // Methods return default of really set values!
         //---------------------------------------------------------------------------------------------------------
         sal_uInt32 getIFlags       () const { return m_nIFlags       ; }
         sal_uInt32 getEFlags       () const { return m_nEFlags       ; }

Modified: openoffice/trunk/main/framework/inc/recording/dispatchrecordersupplier.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/recording/dispatchrecordersupplier.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/inc/recording/dispatchrecordersupplier.hxx (original)
+++ openoffice/trunk/main/framework/inc/recording/dispatchrecordersupplier.hxx Tue Apr 29 19:05:05 2014
@@ -74,7 +74,7 @@ class DispatchRecorderSupplier  :   // i
                                     public  css::lang::XServiceInfo                 ,
                                     public  css::frame::XDispatchRecorderSupplier   ,
                                     // baseclasses
-                                    // Order is neccessary for right initialization!
+                                    // Order is necessary for right initialization!
                                     private ThreadHelpBase                          ,
                                     public  ::cppu::OWeakObject
 {
@@ -86,7 +86,7 @@ class DispatchRecorderSupplier  :   // i
         //_______________________________________
         /** provided dispatch recorder of this supplier instance
 
-            @life   Is controled from outside. Because this variable is setted
+            @life   Is controlled from outside. Because this variable is setted
                     from there and not created internaly. But we release our
                     reference to it if we die.
          */
--- openoffice/trunk/main/framework/inc/helper/ocomponentaccess.hxx (original)
+++ openoffice/trunk/main/framework/inc/helper/ocomponentaccess.hxx Tue Apr 29 19:05:05 2014
@@ -83,7 +83,7 @@ namespace framework{
 	@devstatus		ready to use
 *//*-*************************************************************************************************************/
 
-class OComponentAccess	:	private ThreadHelpBase                      ,   // Must be the first of baseclasses - Is neccessary for right initialization of objects!
+class OComponentAccess	:	private ThreadHelpBase                      ,   // Must be the first of baseclasses - Is necessary for right initialization of objects!
 							public ::cppu::WeakImplHelper1< ::com::sun::star::container::XEnumerationAccess >
 {
 	//-------------------------------------------------------------------------------------------------------------
@@ -199,12 +199,12 @@ class OComponentAccess	:	private ThreadH
 
 		/*-****************************************************************************************************//**
 			@short		recursive method (!) to collect all components of all frames from the subtree of given node
-			@descr		This is neccessary to create the enumeration.
+			@descr		This is necessary to create the enumeration.
 
 			@seealso	method createEnumeration
 
 			@param		"xNode"        , root of subtree and start point of search
-			@param		"seqComponents", result list of search. We cant use a return value, we search recursive
+			@param		"seqComponents", result list of search. We can't use a return value, we search recursive
 										 and must collect all informations.
 			@return		-
 

Modified: openoffice/trunk/main/framework/inc/helper/ocomponentenumeration.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/helper/ocomponentenumeration.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================